PCA9635 16-bit I2C-bus LED driver

Dependents:   digitalThermometer Counter SimpleClock printNumber ... more

Revision:
9:48985b738e5a
Parent:
8:47e2fc119445
Child:
10:b807470a8b09
--- a/PCA9635.h	Wed Jun 29 08:45:40 2011 +0000
+++ b/PCA9635.h	Wed Jun 29 13:39:28 2011 +0000
@@ -77,11 +77,17 @@
         * @param led LED pin coordinates
         */
         void off(char led);
         /**Set all pins passed as argument high or low
         *
         * @param leds Set output according to parameter value - e.g. 0x0003 >> p0 & p1 high, rest low
         */
         void bus(short leds);
+        /**Set all pins passed as argument high or low for specified address
+        *
+        * @param leds Set output according to parameter value - e.g. 0x0003 >> p0 & p1 high, rest low
+        * @param address Display address
+        */
+        void bus(short leds, int address);
         /** Define LED brightness
         *
         * @param led LED pin coordinates
@@ -77,11 +77,17 @@
         */
         void off(char led);
-        /**Set all pins passed as argument high or low
+        /**Set all pins passed as argument high or low for current address
         *
         * @param leds Set output according to parameter value - e.g. 0x0003 >> p0 & p1 high, rest low